import pygame as pg
from .utils import *

class Player(pg.sprite.Sprite):
    """ Cria, movimenta e anima o objeto do player """
    def __init__(self, *groups):
        super().__init__(*groups)
        self.image = pg.image.load(CAMINHO + "/images/player.png")  
        self.image = pg.transform.scale(self.image, (100, 100))  
        self.rect = pg.rect.Rect(HEIGHT//2, WIDTH//2, 100, 100)  
        self.bomb_limit = 50 

    def update(self):
        """ controla toda a movimentação do player """
        keys = pg.key.get_pressed()
        if keys[pg.K_w] or keys[pg.K_UP]:
            self.rect.y -= 5
        if keys[pg.K_s] or keys[pg.K_DOWN]:
            self.rect.y += 5
        if keys[pg.K_a] or keys[pg.K_LEFT]:
            self.rect.x -= 5
        if keys[pg.K_d] or keys[pg.K_RIGHT]:
            self.rect.x += 5
        
        # garante que o player não saia da tela
        if self.rect.top <= 42:
            self.rect.top = 42
        if self.rect.bottom >= 498:
            self.rect.bottom = 498
        if self.rect.left <= 55:
            self.rect.left = 55
        if self.rect.right >= 905:
            self.rect.right = 905



import pygame as pg

from .player import Player
from .bomb import Bomb
from .utils import *

gameObjectGroup = pg.sprite.Group() 
bombGroup = pg.sprite.Group(gameObjectGroup) 

pl = Player(gameObjectGroup)  

class Game(pg.sprite.Sprite):
    """ Esta classe controla somente a execução da partida, não a do programa em si"""
    def __init__(self, *groups):
        super().__init__(*groups)
        self.image = pg.image.load(CAMINHO + "/images/mapa.jpg")
        self.image = pg.transform.scale(self.image, (HEIGHT, WIDTH)).convert()
        self.rect = self.image.get_rect()
        self.running = False

    def update(self):
        if self.running:
            for event in pg.event.get(): 
                if event.type == pg.QUIT:
                    exit()
                if event.type == pg.KEYDOWN: 
                    if event.key == pg.K_ESCAPE:
                        self.running = False
                    if event.key == pg.K_SPACE: 
                        if pl.bomb_limit >= len(bombGroup):  # limita as bombas
                            newBomb = Bomb(gameObjectGroup, bombGroup) 
                            newBomb.rect.center = pl.rect.center  



import pygame as pg
from time import time
from .utils import CAMINHO

class Bomb(pg.sprite.Sprite):
    """ Cria os objetos de bomba, controla a sua explosão e animação"""
    def __init__(self, *groups):
        super().__init__(*groups)
        self.image = pg.image.load(CAMINHO + "/images/bomba.png")
        self.image = pg.transform.scale(self.image, (40, 40))
        self.rect = self.image.get_rect()
        self.explosion_range = 1 
        self.start_time = time()  # pega o momento em que a bomba foi colocada
    

    def update(self):
        self.timer = time() - self.start_time
        if self.timer >= 5:
            self.explosion()
            

    def explosion(self):
        self.kill()
        

        
        
        




import pygame as pg
from .utils import *

class Menu(pg.sprite.Sprite):
    def __init__(self, *groups):
        super().__init__(*groups)
        self.image = pg.image.load(CAMINHO + "/images/menu.jpg")
        self.image = pg.transform.scale(self.image, (HEIGHT, WIDTH))
        self.rect = self.image.get_rect()
        self.button = None

        self.newGame_img = pg.image.load(CAMINHO + "/images/inicio.png")
        self.newGame_img = pg.transform.scale(self.newGame_img, (200, 50))
        self.newGame_rect = pg.rect.Rect(400, WIDTH//2, 200, 50)
        self.image.blit(self.newGame_img, (400, WIDTH//2))

    def update(self):
        pass

    def click(self, m_pos):
        if self.newGame_rect.collidepoint(m_pos):
            self.button = "new_game"
        

class SecondaryMenu(pg.sprite.Sprite):
    """ menu de pausa de quando o jogo tá em execussão """
    def __init__(self, *groups):
        super().__init__(groups)
        self.image = pg.image.load(CAMINHO + "images/secondaryMenu.png")
        self.image = pg.transform.scale(self.image, (HEIGHT, WIDTH))
        self.rect = self.image.get_rect()



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    readme = fh.read()

setup(
    name='BomberNight',
    version="0.0.4post",
    description='Releitura do Bomberman',
    long_description=readme,
    long_description_content_type="text/markdown",
    url='https://github.com/juliohsu/BomberNight',
    author='Júlio Hsu',
    author_email='tst700900@gmail.com',
    license='MIT',
    keywords=[
        'jogo',
        'game',
        'bomberman',
        'arcade',
        'ação'
    ],
    packages=find_packages(),
    install_requires=['pygame>=2.0'],
    entry_points={
        'console_scripts': [
            'bombernight=BomberNight.__main__:main'
        ]
    },
    python_requires='>=3.6',
    include_package_data=True,
)



# VERSION = 0.0.4 

import pygame as pg

pg.init()

display = pg.display.set_mode([960, 540]) 
pg.display.set_caption("BomberNight") 

from .menu import Menu
from .game import Game, gameObjectGroup

menuGroup = pg.sprite.Group()  
gameGroup = pg.sprite.Group()  

mn = Menu(menuGroup)  
gm = Game(gameGroup)

clock = pg.time.Clock()

def run():
    while True:
        clock.tick(30) 
        if gm.running: 
            gameGroup.update()
            gameObjectGroup.update()
            gameGroup.draw(display)
            gameObjectGroup.draw(display)

        else:
            for event in pg.event.get():  
                if event.type == pg.QUIT: 
                    exit()
                if event.type == pg.MOUSEBUTTONDOWN:
                    if event.button == 1:
                        m_pos = pg.mouse.get_pos()
                        mn.click(m_pos)
                        if mn.button == 'new_game':
                            gm.running = True
                            mn.button = False
                        
                menuGroup.update()
                menuGroup.draw(display)

        # atualiza a tela
        pg.display.update()

if __name__ == "__main__":
    run()

